pg.ddx.io  pgsql-performance@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Sven Geisler <sgeisler@aeccom.com>
To: Luke Lonergan <llonergan@greenplum.com>
Cc: Pgsql-Performance ((E-mail)) <pgsql-performance@postgresql.org>
Subject: Re: 64-bit vs 32-bit performance ... backwards?
Date: Tue, 13 Jun 2006 14:03:21 +0200
Message-ID: <448EA989.5000408@aeccom.com> (raw)
In-Reply-To: <C0B3F08F.26F80%llonergan@greenplum.com>
References: <C0B3F08F.26F80%llonergan@greenplum.com>

Luke

Luke Lonergan schrieb:
> On 6/13/06 2:04 AM, "Sven Geisler" <sgeisler@aeccom.com> wrote:
>> Please find attached a small patch with does apply a change to the
>> x86_64 part also to the i386 part of src/include/storage/s_lock.h.
>> Without this change the performance of PostgreSQL 8.0 was horrible on a
>> Opteron. The effect is smaller with PostgreSQL 8.1.
> 
> Can you describe what kinds of tests you ran to check your speed?

I has create a test scenario with parallel client which running mostly 
SELECTs on the same tables. I used a sequence of 25 queries using 10 
tables. We use the total throughput (queries per second) as result.

> 
> Since it's the TAS lock that you are patching, the potential impact is
> diffuse and large: xlog.c, shmem.c, lwlock.c, proc.c, all do significant
> work.

Yes, I know. We had a problem last year with the performance of the 
Opteron. We have started the futex patch to resolve the issue. The futex 
patch itself did have no effect, but there was a side effect because the 
futex patch did use also another assembler sequence. This make a hole 
difference on a Opteron. It turned out that removing the lines

cmpb
jne
lock

was the reason why the Opteron runs faster.
I have created a sequence of larger query with following result on 
Opteron 875 and PostgreSQL 8.0.3
orignal 8.0.3 => 289 query/time and 10% cpu usage
patched 8.0.3 => 1022 query/time and 45% cpu usage

I has a smaller effect on a XEON MP with EM64T. But this effect wasn't 
that huge. There was no effect on classic XEON's.

Cheers
Sven.



view thread (34+ messages)  latest in thread

Message-ID: <448EA989.5000408@aeccom.com>
Permalink:  ../448EA989.5000408@aeccom.com/
Also on:    postgresql.org/message-id/448EA989.5000408@aeccom.com

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-performance@postgresql.org
  Cc: sgeisler@aeccom.com, llonergan@greenplum.com
  Subject: Re: 64-bit vs 32-bit performance ... backwards?
  In-Reply-To: <448EA989.5000408@aeccom.com>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox